# Collections

Timestreams allow each point to contain a collection -- a `list` or `map` -- of elements.

## Collection Methods

```{eval-rst}
.. currentmodule:: kaskada

.. autosummary::
   :toctree: ../apidocs/

    Timestream.__getitem__
    Timestream.flatten
    Timestream.index
    Timestream.length
    Timestream.union
```